@@ -30,6 +30,7 @@
 #include "libgcpcanvas/gprintable.h"
 #include "arrow.h"
 #include "document.h"
+#include <cstring>
 
 gcpArrow::gcpArrow(TypeId Type): Object(Type)
 {
@@ -72,7 +73,7 @@ bool gcpArrow::Load (xmlNodePtr node)
 		SetId (tmp);
 		xmlFree (tmp);
 	}
-	child = GetNodeByName (node, "start");
+	child = GetNodeByName (node, (char*) "start");
 	if (!child) return false;
 	tmp = (char*) xmlGetProp (child, (xmlChar*) "x");
 	if (!tmp) return false;
@@ -88,7 +89,7 @@ bool gcpArrow::Load (xmlNodePtr node)
 	xmlFree (tmp);
 	if (result)
 		return false;
-	child = GetNodeByName (node, "end");
+	child = GetNodeByName (node, (char*) "end");
 	if (!child) return false;
 	tmp = (char*) xmlGetProp (child, (xmlChar*) "x");
 	if (!tmp) return false;
