@@ -33,6 +33,7 @@
 #include "libgcpcanvas/gcp-canvas-rect-ellipse.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
 #include <cmath>
+#include <cstring>
 
 #define POSITION_NE 1
 #define POSITION_NW 2
@@ -179,10 +180,12 @@ void gcpElectron::Add(GtkWidget* w)
 	pData->Items[this] = group;
 }
 
-void gcpElectron::Update(GtkWidget* w)
+void gcpElectron::Update (GtkWidget* w)
 {
 	gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data (G_OBJECT (w), "data");
 	gcpTheme* pTheme = pData->View->GetDoc ()->GetTheme ();
+	if (pData->Items[this] != NULL)
+		return;
 	GnomeCanvasGroup *group = pData->Items[this];
 	double x, y, angle = m_Angle / 180. * M_PI;
 	if (m_Dist != 0.){
