@@ -39,8 +39,9 @@
 #include <gcu/element.h>
 #include <pango/pango-attributes.h>
 #include <glib/gi18n-lib.h>
-#include <math.h>
 #include <list>
+#include <cmath>
+#include <cstring>
 
 static void on_fragment_changed (gcpFragment *fragment)
 {
@@ -59,7 +60,7 @@ gcpFragment::gcpFragment (): gcpTextObject (FragmentType)
 	m_StartSel = m_EndSel = 0;
 	m_lbearing = 0;
 	m_CHeight = 0.;
-	SetId ("f1");
+	SetId ((char*) "f1");
 }
 
 gcpFragment::gcpFragment (double x, double y): gcpTextObject (x, y, FragmentType)
@@ -69,7 +70,7 @@ gcpFragment::gcpFragment (double x, double y): gcpTextObject (x, y, FragmentType
 	m_BeginAtom = m_EndAtom = 0;
 	m_lbearing = 0;
 	m_CHeight = 0.;
-	SetId ("f1");
+	SetId ((char*) "f1");
 }
 
 gcpFragment::~gcpFragment ()
@@ -328,8 +329,8 @@ void gcpFragment::SetSelected (GtkWidget* w, int state)
 	gchar *chargecolor, *color;
 	switch (state) {	
 	case SelStateUnselected:
-		color = "white";
-		chargecolor = "black";
+		color = (char*) "white";
+		chargecolor = (char*) "black";
 		break;
 	case SelStateSelected:
 		chargecolor = color = SelectColor;
@@ -341,8 +342,8 @@ void gcpFragment::SetSelected (GtkWidget* w, int state)
 		chargecolor = color = DeleteColor;
 		break;
 	default:
-		color = "white";
-		chargecolor = "black";
+		color = (char*) "white";
+		chargecolor = (char*) "black";
 		break;
 	}
 	g_object_set (G_OBJECT (g_object_get_data (G_OBJECT (group), "rect")),
@@ -357,6 +358,8 @@ void gcpFragment::SetSelected (GtkWidget* w, int state)
 void gcpFragment::Update (GtkWidget* w)
 {
 	gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data (G_OBJECT (w), "data");
+	if (pData->Items[this] != NULL)
+		return;
 	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	GnomeCanvasGroup *group = pData->Items[this];
 	g_object_set (G_OBJECT (g_object_get_data (G_OBJECT (group), "fragment")),
@@ -738,6 +741,7 @@ void gcpFragment::AnalContent (unsigned start, unsigned &end)
 	unsigned start_tag, end_tag, next;
 	char c;
 	ChargeFindStruct s;
+	s.index = s.end = 0;
 	if (start > 0) {
 		// search if a charge is at preceeding character
 		s.result = false;
@@ -992,8 +996,8 @@ int gcpFragment::GetChargePosition (gcpFragmentAtom *pAtom, unsigned char &Pos,
 		if ((result & CHARGE_SE) && (angle >= 90.0) && (angle <= 180.0)) result -= CHARGE_SE;
 		if ((result & CHARGE_SW) && (((angle >= 0.0) && (angle <= 90.0)) || (fabs(angle - 360.0) < 0.1))) result -= CHARGE_SW;
 		if ((result & CHARGE_S) && (angle >= 45.0) && (angle <= 135.0)) result -= CHARGE_S;
-		if ((result & CHARGE_E) && ((angle <= 225.0) && (angle >= 135.0))) result -= CHARGE_E;
-		if ((result & CHARGE_W) && (angle >= 315.0) || (angle <= 45.0)) result -= CHARGE_W;
+		if ((result & CHARGE_E) && (angle <= 225.0) && (angle >= 135.0)) result -= CHARGE_E;
+		if ((result & CHARGE_W) && ((angle >= 315.0) || (angle <= 45.0))) result -= CHARGE_W;
 	}
 	if (Pos == 0xff) {
 		if (result) {
