@@ -33,14 +33,16 @@
 #include "widgetdata.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
 #include "libgcpcanvas/gcp-canvas-line.h"
-#include <math.h>
+#include <cmath>
+#include <cstring>
 
 gcpReactionArrow::gcpReactionArrow (gcpReaction* react, unsigned Type): gcpArrow (ReactionArrowType)
 {
-	SetId ("ra1");
+	SetId ((char*) "ra1");
 	m_Type = Type;
 	m_Start = m_End = NULL;
 	if (react) react->AddChild (this);
+	m_TypeChanged = false;
 }
 
 
@@ -256,6 +258,8 @@ void gcpReactionArrow::Add (GtkWidget* w)
 void gcpReactionArrow::Update (GtkWidget* w)
 {
 	gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data (G_OBJECT (w), "data");
+	if (pData->Items[this] != NULL)
+		return;
 	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	GnomeCanvasGroup* group = pData->Items[this];
 	if (!group) {
@@ -285,6 +289,7 @@ void gcpReactionArrow::Update (GtkWidget* w)
 								NULL);
 			break;
 		case gcpReversibleArrow:
+		case gcpFullReversibleArrow:
 			double dAngle = atan (- m_height / m_width);
 			if (m_width < 0) dAngle += M_PI;
 			points->coords[0] = m_x * pTheme->GetZoomFactor () - pTheme->GetArrowDist () / 2 * sin (dAngle);
