@@ -36,6 +36,7 @@
 #include "libgcpcanvas/gprintable.h"
 #include <glib/gi18n-lib.h>
 #include <stdexcept>
+#include <cstring>
 
 static void on_text_changed (gcpText *text)
 {
@@ -146,30 +147,30 @@ static bool save_state (xmlDocPtr xml, xmlNodePtr node, char const *t, SaveStruc
 		char *stretch = NULL;
 		switch (st) {
 		case PANGO_STRETCH_ULTRA_CONDENSED:
-			stretch = "ultra-condensed";
+			stretch = (char*) "ultra-condensed";
 			break;
 		case PANGO_STRETCH_EXTRA_CONDENSED:
-			stretch = "extra-condensed";
+			stretch = (char*) "extra-condensed";
 			break;
 		case PANGO_STRETCH_CONDENSED:
-			stretch = "condensed";
+			stretch = (char*) "condensed";
 			break;
 		case PANGO_STRETCH_SEMI_CONDENSED:
-			stretch = "semi-condensed";
+			stretch = (char*) "semi-condensed";
 			break;
 		case PANGO_STRETCH_NORMAL:
 			break;
 		case PANGO_STRETCH_SEMI_EXPANDED:
-			stretch = "semi-expanded";
+			stretch = (char*) "semi-expanded";
 			break;
 		case PANGO_STRETCH_EXPANDED:
-			stretch = "expanded";
+			stretch = (char*) "expanded";
 			break;
 		case PANGO_STRETCH_EXTRA_EXPANDED:
-			stretch = "extra-expanded";
+			stretch = (char*) "extra-expanded";
 			break;
 		case PANGO_STRETCH_ULTRA_EXPANDED:
-			stretch = "ultra-expanded";
+			stretch = (char*) "ultra-expanded";
 			break;
 		}
 		if (!stretch)
@@ -198,13 +199,13 @@ static bool save_state (xmlDocPtr xml, xmlNodePtr node, char const *t, SaveStruc
 		case PANGO_UNDERLINE_SINGLE:
 			break;
 		case PANGO_UNDERLINE_DOUBLE:
-			type = "double";
+			type = (char*) "double";
 			break;
 		case PANGO_UNDERLINE_LOW:
-			type = "low";
+			type = (char*) "low";
 			break;
 		case PANGO_UNDERLINE_ERROR:
-			type = "error"; // not really implemented
+			type = (char*) "error"; // not really implemented
 			break;
 		}
 		if (u == PANGO_UNDERLINE_NONE)
@@ -697,6 +698,8 @@ bool gcpText::OnChanged (bool save)
 void gcpText::Update(GtkWidget* w)
 {
 	gcpWidgetData* pData = (gcpWidgetData*)g_object_get_data(G_OBJECT(w), "data");
+	if (pData->Items[this] != NULL)
+		return;
 	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	GnomeCanvasGroup* group = pData->Items[this];
 	g_object_set(G_OBJECT(g_object_get_data(G_OBJECT(group), "text")),
@@ -720,7 +723,7 @@ void gcpText::SetSelected(GtkWidget* w, int state)
 	gchar* color;
 	switch (state) {	
 	case SelStateUnselected:
-		color = "white";
+		color = (char*) "white";
 		break;
 	case SelStateSelected:
 		color = SelectColor;
@@ -732,7 +735,7 @@ void gcpText::SetSelected(GtkWidget* w, int state)
 		color = DeleteColor;
 		break;
 	default:
-		color = "white";
+		color = (char*) "white";
 		break;
 	}
 	g_object_set(G_OBJECT(g_object_get_data(G_OBJECT(group), "rect")), "outline_color", color, NULL);
