@@ -33,13 +33,13 @@
 #include "lib/widgetdata.h"
 #include "libgcpcanvas/gcp-canvas-bpath.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
-#include <math.h>
+#include <cmath>
 
 TypeId RetrosynthesisArrowType = NoType;
 
 gcpRetrosynthesisArrow::gcpRetrosynthesisArrow(gcpRetrosynthesis *rs): gcpArrow (RetrosynthesisArrowType)
 {
-	SetId ("rsa1");
+	SetId ((char*) "rsa1");
 	if (rs)
 		rs->AddChild( this);
 	m_Start = m_End = NULL;
@@ -163,6 +163,8 @@ void gcpRetrosynthesisArrow::Add (GtkWidget* w)
 void gcpRetrosynthesisArrow::Update (GtkWidget* w)
 {
 	gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data (G_OBJECT (w), "data");
+	if (pData->Items[this] != NULL)
+		return;
 	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	GnomeCanvasGroup* group = pData->Items[this];
 	double x0, y0, x1, y1, dx, dy, dAngle;
